# -*- coding: utf-8 -*-
# Copyright 2011 Thamini S.à.R.L    This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import netsvc
from osv import osv
from osv import fields
from tools.translate import _

class insurance_contract_declare_claim_wizard(osv.osv_memory):
    _name = 'insurance.contract.declare.claim.wizard'
    _columns = {
        'contract_id': fields.many2one('insurance.contract', 'Contract', required=True, readonly=True),
        'responsible_id': fields.many2one('res.users', 'Expert', required=True),
        'date': fields.datetime('Date', required=True),
        'report_note': fields.text('Report Note', required=True),
        'report_data': fields.binary('Report', help='If you do not provide any document, the claim will not be marked as received'),
        'report_filename': fields.char('Report Name', size=255),
    }

    def _default_responsible_id(self, cr, uid, context=None):
        """
        Get the default responsible id.
          If current user is an 'Insurance Expert' return the current uid,
          otherwise return False
        :param cr: database cursor
        :param uid: current user id
        :param context: current request context
        :return: user_id
        """
        ima_proxy = self.pool.get('ir.model.access')
        if ima_proxy.check_groups(cr, uid, 'insurance.group_insurance_expert'):
            return uid
        return False

    def _default_contract_id(self, cr, uid, context=None):
        """
        Get the default contract id from context

        :param cr: database cursor
        :param uid: current user id
        :param context: curent request context
        :return: contract_id
        """
        if not context:
            return False
        return context.get('active_id',False)

    _defaults = {
        'responsible_id': _default_responsible_id,
        'contract_id': _default_contract_id,
    }

    def button_create_claim(self, cr, uid, ids, context=None):
        claim_proxy = self.pool.get('insurance.claim')
        attach_proxy = self.pool.get('ir.attachment')
        imd_proxy = self.pool.get('ir.model.data')

        if not ids:
            return {}
        wizard = self.browse(cr, uid, ids[0], context=context)
        dummy, type_id = imd_proxy.get_object_reference(cr, uid, 'insurance', 'type_expert_report_claim_declaration')
        type =         claim_data = {
            'contract_id': wizard.contract_id.id,
            'date': wizard.date,
            'expert_note': wizard.report_note,
            'expert_report_ids': [
                (0, 0, {
                    'type_id': type_id,
                    'contract_id': wizard.contract_id.id,
                    'responsible_id': wizard.responsible_id.id,
                    'responsible_summary': wizard.report_note,
                    # TODO: report datas
                })
            ],
        }
        new_claim_id = claim_proxy.create(cr, uid, claim_data, context=context)
        claim = claim_proxy.browse(cr, uid, new_claim_id, context=context)
        if wizard.report_data and wizard.report_filename:
            attach_data = {
                'name': wizard.report_filename,
                'datas': wizard.report_data,
                'datas_fname': wizard.report_filename,
                'res_model': 'insurance.expert.report',
                'res_id': claim.expert_report_ids[0].id,
            }
            attach_proxy.create(cr, uid, attach_data, context=context)
            # mark the claim as already received because we already have the claim declaration document
            workflow = netsvc.LocalService('workflow')
            workflow.trg_validate(uid, 'insurance.claim', new_claim_id, 'signal_receive', cr)
        return {
            'type': 'ir.actions.act_window',
            'res_model': 'insurance.claim',
            'view_type': 'form',
            'view_mode': 'form,tree',
            'res_id': new_claim_id,
        }

insurance_contract_declare_claim_wizard()
